#define gmeCreate
/*
    Defines the external functions.
    You must call this first, preferably in the Creation Code of the first room in the game.
*/

global.gmeObject = object_add();

global.mvInit = external_define("GMGME.DLL","gmeInit",dll_stdcall,ty_real,1,ty_string);
global.mvInitExt = external_define("GMGME.DLL","gmeInitExt",dll_stdcall,ty_real,2,ty_string,ty_real);

global.mvClose = external_define("GMGME.DLL","gmeClose",dll_stdcall,ty_real,0);
global.mvLoad = external_define("GMGME.DLL","gmeLoad",dll_stdcall,ty_real,1,ty_string);
global.mvPlay = external_define("GMGME.DLL","gmePlay",dll_stdcall,ty_real,0);
global.mvStop = external_define("GMGME.DLL","gmeStop",dll_stdcall,ty_real,0);
global.mvPause = external_define("GMGME.DLL","gmePause",dll_stdcall,ty_real,0);
global.mvGetTracks = external_define("GMGME.DLL","gmeGetTracks",dll_stdcall,ty_real,0);
global.mvSetTrack  = external_define("GMGME.DLL","gmeSetTrack",dll_stdcall,ty_real,1,ty_real);
global.mvNextTrack = external_define("GMGME.DLL","gmeNextTrack",dll_stdcall,ty_real,0);
global.mvSetVolume = external_define("GMGME.DLL","gmeSetVolume",dll_stdcall,ty_real,1,ty_real);
global.mvGetSample = external_define("GMGME.DLL","gmeGetSample",dll_stdcall,ty_real,0);

// New functions
global.mvSetStereoDepth = external_define("GMGME.DLL","gmeSetStereoDepth",dll_stdcall,ty_real,1,ty_real);
global.mvSetTempo = external_define("GMGME.DLL","gmeSetTempo",dll_stdcall,ty_real,1,ty_real);
global.mvIsPlaying = external_define("GMGME.DLL","gmeIsPlaying",dll_stdcall,ty_real,0);
global.mvIsStopped = external_define("GMGME.DLL","gmeIsStopped",dll_stdcall,ty_real,0);



#define gmeLoad
/* Should be kinda obvious.
   Anyways, the file types that can be loaded (Quoted from the gme readme) are as follows:
   
        AY        ZX Spectrum/Amstrad CPC
        GBS       Nintendo Game Boy
        GYM       Sega Genesis/Mega Drive
        HES       NEC TurboGrafx-16/PC Engine
        KSS       MSX Home Computer/other Z80 systems (doesn't support FM sound)
        NSF/NSFE  Nintendo NES/Famicom (with VRC 6, Namco 106, and FME-7 sound)
        SAP       Atari systems using POKEY sound chip
        SPC       Super Nintendo/Super Famicom
        VGM/VGZ   Sega Master System/Mark III, Sega Genesis/Mega Drive,BBC Micro
   
   Some of these formats (NSF comes to mind especially) support multiple tracks. Use gmeGetTracks() to find out.
   Note that this function does NOT start playing the song, it just loads it.
*/

// Arguments: 1
// filename (EG: "mymusic.nsf")

var filename;
filename = argument0;

external_call(global.mvLoad,filename);



#define gmeClose
/*
    Stops the song and frees the memory used by the DLL
    You don't have to call this, the object created in gmeCreate
    takes care of that.
*/

external_call(global.mvClose);

#define gmePlay
/* 
    Plays the currently loaded song.
    Loops automatically if the song supports it.
    * Takes no arguments
*/

external_call(global.mvPlay);

#define gmeStop
/*
    Does what it advertises. Stops the currently loaded song.
    * Takes no arguments
*/

external_call(global.mvStop);

#define gmePause
/*
    Pause toggles, note, _TOGGLES_, the paused state for the currently
    loaded song. Therefore, if you call it twice on a playing song,
    the song will jump from Playing->Paused->Playing again.
    This is intentional, by the way :3
    *Takes no arguments
*/

external_call(global.mvPause);


#define gmeGetTracks
/* 
    Returns the number of available tracks in the current file.
    *Takes no arguments
*/

return external_call(global.mvGetTracks);

#define gmeSetTrack
/* 
    Sets the track to argument0. 
    Won't try load tracks that don't exist.
    * Takes 1 argument, track_number
*/

var track_number;
track_number = argument0;

external_call(global.mvSetTrack,track_number);

#define gmeNextTrack
/* 
    Hops to the next track if there is one
    *No arguments
*/

external_call(global.mvNextTrack);

#define gmeSetVolume
/*
    Sets the volume...
    *Takes one argument, real number between 0.0 and 100.0
    *Nice fadeouts work with this, unlike MID's or MP3's.
*/

var volume;
volume = argument0;
if(volume > 100)volume = 100;
if(volume < 0)volume = 0;

external_call(global.mvSetVolume,volume);

#define gmeGetSample
// Returns a sample value


//return external_call(global.mvGetSample);

//Averaged
samps[32] = 0;
for(i = 0; i < 32; i+=1)
{
    samps[i] = external_call(global.mvGetSample);
}
san = 0;
for(i = 0; i < 32; i+=1)
{
    san += samps[i];
}

return floor(san/32);

#define gmeSetStereoDepth
// Sets the stereo depth
// Takes one argument between 0.0 (Default) and 1.0

external_call(global.mvSetStereoDepth,argument0);

#define gmeSetTempo
// Sets the song's tempo
// Takes one argument between 0.0 (Default) and 1.0

external_call(global.mvSetTempo,argument0);

#define gmeIsStopped
return external_call(global.mvIsStopped);

#define gmeIsPlaying
return external_call(global.mvIsPlaying);

